# Disable the automatically set build flags to the environment variables such
# as CC, CFLAGS, and etc.
# See <https://src.fedoraproject.org/rpms/redhat-rpm-config/blob/rawhide/f/macros>.
%undefine _auto_set_build_flags

Name: simde
Version: v0.8.0
Release: 1.20240418141750295206.pr1173.35.gb2eb6b8e%{?dist}
Summary: Dummy
License: MIT
URL: https://github.com/simd-everywhere/simde
# This value is magically replaced with the archive tar.gz file created by
# `git archive` in the process of the CI.
# Set the existing file `README.md` in case of creating SRPM from this RPM spec
# file on local for testing purpose.
Source0: simde-v0.8.0.tar.gz
# A path to the CI script.
Source1: ci.sh

# List up the needed RPM package names to test here.
# clang, clang++
BuildRequires: clang
BuildRequires: gcc
# g++
BuildRequires: gcc-c++
# ninja
BuildRequires: ninja-build
# pip and setuptools are needed to install and use meson PyPI package.
BuildRequires: python3-devel
BuildRequires: python3-pip
BuildRequires: python3-setuptools
# The GNU time (/bin/time) is used for testing. Use this GNU time rather than
# the embedded time function in bash.
# https://www.gnu.org/software/time/
BuildRequires: time

# RPM package description.
%description

# The bash commands to prepare are executed.
%prep
# Print the replaced value of the Source0.
echo "Source0: %{SOURCE0}"
# Create a dummy file for a valid RPM spec file.
touch dummy.txt

# The bash commands to test are executed.
%check
# Check the directory structure in the tar.gz file.
tar tzvf "%{SOURCE0}" > source_files.txt
head -2 source_files.txt
# Check if the submodule munit is included.
grep munit source_files.txt
# Extract the source archive file.
tar xzf "%{SOURCE0}"

pushd simde-*
# Set the flags used to build the actual RPM package.
# These can be used in the CI testing script.
%global toolchain clang
export CI_CLANG_RPM_CFLAGS="%{build_cflags}"
export CI_CLANG_RPM_CXXFLAGS="%{build_cxxflags}"
export CI_CLANG_RPM_LDFLAGS="%{build_ldflags}"
%global toolchain gcc
export CI_GCC_RPM_CFLAGS="%{build_cflags}"
export CI_GCC_RPM_CXXFLAGS="%{build_cxxflags}"
export CI_GCC_RPM_LDFLAGS="%{build_ldflags}"

echo "Running the CI script %{SOURCE1}."
/bin/time -f '=> [%E]' "%{SOURCE1}"
popd

# Files included in the built RPM package.
%files
%doc dummy.txt

# Changelog entries for the RPM package.
%changelog
* Thu Apr 18 2024 Packit <hello@packit.dev> - v0.8.0-1.20240418141750295206.pr1173.35.gb2eb6b8e
- arm: fix some neon2rvv intrinsic function error (Zhijin Zeng)
- arm: enable more intrinsic function for armv7 (Zhijin Zeng)
- wasm x86 impl: some were incorrectly marked SSE instead of SSE2 (Michael R. Crusoe)
- arm x86 implementations: allow _m128 access from SSE (Michael R. Crusoe)
- tests x86, adjust import order so that MSVC pragma are processed early (Michael R. Crusoe)
- svml: SSE is good enough for native m128i and m128d types & functions (Michael R. Crusoe)
- sse2 MSVC `_mm_pause` implementaiton for x86 (Michael R. Crusoe)
- x86 test msvc: really disable warning 4799,4730 (Michael R. Crusoe)
- typo fixes from codespell (Michael R. Crusoe)
- README.md - move CLMUL to partial, list more of the CI.yml architectures (Torinde)
- Update README.md - link to VPCLMULQDQ; mention MSA (#1157) (Torinde)
- Update README.md (#1156) (Michael R. Crusoe)
- Packit: Drop i386 (i686) support. (#1155) (Jun Aruga)
- gh-actions: build for AMD Buildozer version 2 (Michael R. Crusoe)
- x86 xop: fix some native functions (Michael R. Crusoe)
- emscripten; use `__builtin_roundeven{f,}` from version 3.1.43 onwards (Michael R. Crusoe)
- arm 32 bits: native def fixes; workarounds for gcc (Cuda-Chen)
- Add gcc arm 32bit armv8-a test in CI (Cuda-Chen)
- CI: don't run twice on dependabot branches (Michael R. Crusoe)
- gh-actions codecov: use token (Michael R. Crusoe)
- build(deps): bump codecov/codecov-action from 3 to 4 (dependabot[bot])
- update list of fully implemented instruction sets (#1152) (Michael R. Crusoe)
- apple clang arm64: ignore SHA2 (Michael R. Crusoe)
- semaphore: stop testing on GCC 5 & 6, clang 3.9 & 4 due to forced upgrade to Ubuntu 20.04 (Michael R. Crusoe)
- gh-actions macos: report log if there is a configuration failure. (Michael R. Crusoe)
- arm platform: cleanup feature detection. (Michael R. Crusoe)
- arm neon sm3: check constant range (Michael R. Crusoe)
- arm neon: disable some FCVTZS/FCVTMS/FCVTPS/FCVTNS family intrinsics (Michael R. Crusoe)
- cirrus: upgrade to clang-17 (Michael R. Crusoe)
- gh-actions: test Mac arm64 (Michael R. Crusoe)
- arm neon clang: skip vrnd native before clang v18 (Michael R. Crusoe)
- clang: detect versions 18 & 19 (Michael R. Crusoe)
- build(deps): bump actions/checkout from 3 to 4 (#1149) (dependabot[bot])
- Initial Support for the RISC-V Vector Extension in ARM NEON (#1130) (Eric Su)
- start next development cycle: v0.8.1 (Michael R. Crusoe)

* Fri Jun 02 2023 Dummy Dummy <dummy@dummy.com> - 1-1
- Dummy.
